@@ -27,12 +27,12 @@ mvar <- function(data,         # n x p data matrix
                  saveModels,   # defaults to TRUE, saves all estimated models
                  saveData,     # defaults to FALSE, saves the data, =TRUE makes sense for easier prediction routine in predict.mgm()
                  overparameterize,
+                 thresholdCat,
                  signInfo,
                  ...
 )
 
 
-
 {
   
   
@@ -65,7 +65,7 @@ mvar <- function(data,         # n x p data matrix
   if(missing(beepvar)) beepvar <- NULL
   if(missing(dayvar)) dayvar <- NULL
   # no AND rule necessary
-  if(missing(weights)) weights <- rep(1, n-max(lags))
+  if(missing(weights)) weights <- rep(1, n)
   if(missing(threshold)) threshold <- 'LW'
   if(missing(method)) method <- 'glm'
   
@@ -85,6 +85,7 @@ mvar <- function(data,         # n x p data matrix
   if(missing(saveModels)) saveModels <- TRUE
   if(missing(saveData)) saveData <- FALSE
   if(missing(overparameterize)) overparameterize <- FALSE
+  if(missing(thresholdCat)) if(overparameterize) thresholdCat <- TRUE else thresholdCat <- TRUE # always better
   if(missing(signInfo)) signInfo <- TRUE
   
   if(missing(scale)) scale <- TRUE
@@ -161,7 +162,7 @@ mvar <- function(data,         # n x p data matrix
   if(sum(!(type %in% c('g', 'c', 'p')))>0) stop("Only Gaussian 'g', Poisson 'p' or categorical 'c' variables permitted.")
   if(ncol(data) != length(type)) stop('Number of variables is not equal to length of type vector.')
   if(!missing(level)) if(ncol(data) != length(level)) stop('Number of variables is not equal to length of level vector.')
-  if((nrow(data)-max(lags)) != length(weights)) stop('Weights vector has to be equal to the number of observations n - max(lags)')
+  if((nrow(data)) != length(weights)) stop('Weights vector has to be equal to the number of observations')
   
   # Are Poisson variables integers?
   if('p' %in% type) {
@@ -211,17 +212,13 @@ mvar <- function(data,         # n x p data matrix
   
   data_response <- data_lagged$data_response
   l_data_lags <- data_lagged$l_data_lags
-  
   n_design <- nrow(data_response)
   
-  # make indicator(included) vector smaller, because the first max(nlags) time steps are already excluded from the data
-  ind_included_wo_begin <- data_lagged$included[-c(1:max_lags)] 
-  
-  data_response <- data_response[ind_included_wo_begin, ]
-  l_data_lags <- lapply(l_data_lags, function(x) x[ind_included_wo_begin, ])
-  
-  # weights <- weights[ind_included_wo_begin]
-  weights_design <- weights[ind_included_wo_begin] # to length of design matrix
+  # delete rows that cannot be predicted
+  data_response <- data_response[data_lagged$included, ]
+  l_data_lags <- lapply(l_data_lags, function(x) x[data_lagged$included, ])
+
+  weights_design <- weights[data_lagged$included] # to length of design matrix
   nadj <- sum(weights_design)
   
   
@@ -230,16 +227,25 @@ mvar <- function(data,         # n x p data matrix
   if(!is.null(args$bootstrap)) {
     if(args$bootstrap) {
       
+      # overwrite above
+      data_lagged <- lagData(data = data, 
+                             lags = lags, 
+                             consec = NULL) # consec comes out of the bootstrap args$boot_ind
+      
+      data_response <- data_lagged$data_response
+      l_data_lags <- data_lagged$l_data_lags
+      
       # overwrite data with bootstrap sample, passed on from resample()
-      data_response <- data_response[args$boot_ind, ]
+      data_response <- data_response[args$boot_ind, ] # args$boot_ind is defined such that it only selects valid rows
       l_data_lags <- lapply(l_data_lags, function(x) x[args$boot_ind, ])
       
       # overwrite weights
-      weights_design <- weights_design[args$boot_ind]
+      weights_design <- weights[args$boot_ind]
       
     }
   }
   
+  # browser()
   
   # -------------------- Input Checks Local (for each set of predictors) -------------------
   
@@ -256,7 +262,7 @@ mvar <- function(data,         # n x p data matrix
     
   }
   
-  
+  # browser()
   
   # ----- Storage: Create empty mgm object -----
   
@@ -300,6 +306,7 @@ mvar <- function(data,         # n x p data matrix
                        'saveModels' = saveModels,
                        'saveData' = saveData,
                        'overparameterize' = overparameterize,
+                       "thresholdCat" = thresholdCat,
                        'signInfo' = signInfo)
   
   # Save original data  
@@ -312,6 +319,9 @@ mvar <- function(data,         # n x p data matrix
     mvarobj$call$data_lagged$data_response <- NULL
   }
   
+  # Save computed consec (if provided by dayvar/beepvar); will be used in prediction functions
+  mvarobj$call$consec <- consec
+  
   
   # -------------------- Estimate -------------------
   
@@ -324,7 +334,7 @@ mvar <- function(data,         # n x p data matrix
   
   for(v in 1:p) {
     
-    
+
     # ----- Create VAR Design Matrix -----
     
     # append response with predictors
@@ -356,7 +366,8 @@ mvar <- function(data,         # n x p data matrix
                             type = type_aug,
                             level = level_aug,
                             labels = colnames(data_input_MM),
-                            d = 1)
+                            d = 1, 
+                            v = NULL)
       X <- X_over
       
     } else {
@@ -366,6 +377,7 @@ mvar <- function(data,         # n x p data matrix
     }
     
     
+    # browser()
     
     
     # ----- Fit each neighborhood using the same procedure as in mgm -----
@@ -418,7 +430,8 @@ mvar <- function(data,         # n x p data matrix
                                             type = type,
                                             level = level,
                                             emp_lev = emp_lev,
-                                            overparameterize = overparameterize)
+                                            overparameterize = overparameterize,
+                                            thresholdCat = thresholdCat)
             
             # Calculte Out-of-sample deviance for current fold
             LL_model <- calcLL(X = test_X,
@@ -475,7 +488,8 @@ mvar <- function(data,         # n x p data matrix
                        type = type,
                        level = level,
                        emp_lev = emp_lev,
-                       overparameterize = overparameterize)
+                       overparameterize = overparameterize,
+                       thresholdCat = thresholdCat)
       
       mvarobj$nodemodels[[v]] <- model
       
@@ -508,7 +522,8 @@ mvar <- function(data,         # n x p data matrix
                                       type = type,
                                       level = level,
                                       emp_lev = emp_lev,
-                                      overparameterize = overparameterize)
+                                      overparameterize = overparameterize,
+                                      thresholdCat = thresholdCat)
         
         EBIC_Seq[a] <- l_alphaModels[[a]]$EBIC
         
@@ -700,6 +715,10 @@ mvar <- function(data,         # n x p data matrix
   list_wadj <- list_signs <- list()
   
   a_wadj <- a_signs <- array(dim = c(p, p, n_lags))
+  
+  
+  # browser()
+  
   a_edgecolor <- array('darkgrey', dim = c(p, p, n_lags))
   mvarobj$rawlags <- vector('list', length = n_lags)
   
